import json
import requests
import matplotlib.pyplot as plt

data= requests.get('https://data.agglo-carene.fr/explore/dataset/214401846_prenoms_liste/download/?format=json&timezone=Europe/Berlin&lang=fr')

def find(name,s,d):
    """Rechercher le nombre d'enfants nées à saint-nazaire par années en fonction du prénom

    Parameters
    ----------
    name : string
        Le prénom recherché (exemple: "Henri")
    s : string
        Le sexe (exemple : "M")
    d : string
        données brutes fournies par l'opendata (format json)

    Returns
    -------
    years : list
        Liste des années où le prénom a été donné
    nbs : list
        Liste des occurences du prénom
    """
    years=[]
    nbs=[]
    tabJSON = json.loads(d.text)
    for objetJSON in tabJSON:
        if objetJSON['fields']['enfant_prenom']==name and objetJSON['fields']['enfant_sexe']==s:
            years.append(int(objetJSON['fields']['annee']))
            nbs.append(int(objetJSON['fields']['nombre_occurences']))
    return years,nbs

annees=[]
occ=[]
annees,occ=find("Sacha","M",data)
print(annees)
print(occ)

def tri(liste1,liste2):
    """Trier deux listes en parallèle
    Les éléments de liste1 sont triés par ordre croissant
    Les éléments de liste2 sont déplacés en parallèle de ceux de liste1

    Parameters
    ----------
    liste1 : list
        Les années où le prénom a été donné (liste non ordonnée)
    liste2 : list
        Les occurences du prénom (ordonnées en fonction des années)

    Returns
    -------
    L1 : list
        Les années où le prénom a été donné par odre chronologique
    L2 : list
        Liste des occurences du prénom (ordonnées en fonction des années)
    """
    L1 = list(liste1)
    L2 = list(liste2)
    N = len(L1)
    for n in range(1,N):
        cle1 = L1[n]
        cle2 = L2[n]
        j = n-1
        while j>=0 and L1[j] > cle1:
            L1[j+1] = L1[j]
            L2[j+1] = L2[j]
            j = j-1
        L1[j+1] = cle1
        L2[j+1] = cle2
    return L1,L2
    
annees_t=[]
occ_t=[]
annees_t,occ_t=tri(annees,occ)
print(annees_t)
print(occ_t)

def graphe(x,y,color):
    plt.plot(x, y, color)
    plt.show()

graphe(annees_t,occ_t,'b')